/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package cz.muni.fi.pv168.localedemo;

import java.text.Collator;
import java.text.DateFormat;
import java.text.NumberFormat;
import java.time.ZoneId;
import java.time.ZonedDateTime;
import java.time.format.DateTimeFormatter;
import java.time.format.FormatStyle;
import java.time.format.TextStyle;
import java.util.Arrays;
import java.util.Date;
import java.util.Locale;
import java.util.TimeZone;

/**
 *
 * @author tomp
 */
public class LocaleDemo {

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        
        final TimeZone timeZone = TimeZone.getTimeZone("Europe/Prague");
        //showLocalTime7(Locale.getDefault(), timeZone);
        
        final ZoneId zoneOf = ZoneId.of("Europe/Prague");
        //showLocalTime8(Locale.getDefault(), zoneOf);
        
        //showNumbers(Locale.getDefault());
        
        sort();
    }

    // classical (upto Java 7) solution
    public static void showLocalTime7(Locale locale, TimeZone tz) {
        Date now = new Date();
        String zoneName = tz.getDisplayName(tz.inDaylightTime(now), TimeZone.LONG, locale);
        DateFormat full = DateFormat.getDateTimeInstance(DateFormat.SHORT, DateFormat.FULL, locale);
        full.setTimeZone(tz);
        System.out.println(locale + ": " + full.format(now) + " (" + zoneName + ")");
        //System.out.println(full.getClass());
    }

    // Java 8 solution
    public static void showLocalTime8(Locale locale, ZoneId tz) {
        ZonedDateTime now = ZonedDateTime.now(tz);
        String zoneName = tz.getDisplayName(TextStyle.FULL, locale);
        DateTimeFormatter full = DateTimeFormatter.ofLocalizedDateTime(FormatStyle.FULL).withLocale(locale);
        System.out.println(locale + ": " + full.format(now) + " (" + zoneName + ")");

    }
    
    public static void showNumbers(Locale locale) { 
        NumberFormat czPlain = NumberFormat.getNumberInstance(locale);
        System.out.println(czPlain.format(1234.56)); // plain -> decimal comma in CZ
        
        NumberFormat czInteger = NumberFormat.getIntegerInstance(locale);
        System.out.println(czInteger.format(1234.56)); // integer -> rounds up
        
        NumberFormat czNF = NumberFormat.getCurrencyInstance(locale);
        System.out.println(czNF.format(1234.56)); // money -> Kč
        
        NumberFormat czPercent = NumberFormat.getPercentInstance(locale);
        System.out.println(czPercent.format(1234.567)); // percent (integer)
    }

    public static void sort() {
        String[] pole = new String[]{
            "Ďoubal",
            "Cezilka",
            "Čeněk",
            "Chranislava",
            "Ilona",
            "Dana",
            "Dřislava",
            "Anička"
        };

        Locale cestina = new Locale("cs", "CZ");
        Locale usa = Locale.US;

        final Collator csCollator = Collator.getInstance(cestina);
        final Collator usaCollator = Collator.getInstance(usa);

        Arrays.sort(pole, csCollator);
        System.out.println("cs : " + Arrays.asList(pole));
        Arrays.sort(pole, usaCollator);
        System.out.println("usa: " + Arrays.asList(pole));
    }
}
